@@ -1,7 +1,7 @@
 ## no critic (RequireUseStrict)
 package Dist::Zilla::Plugin::Test::LocalBrew;
 {
-  $Dist::Zilla::Plugin::Test::LocalBrew::VERSION = '0.04';
+  $Dist::Zilla::Plugin::Test::LocalBrew::VERSION = '0.05';
 }
 
 use File::Spec;
@@ -48,10 +48,22 @@ use strict;
 use warnings;
 
 use FindBin;
+use File::Copy qw(copy);
 use File::Spec;
 use File::Temp;
 use Test::More;
 
+sub copy_log_file {
+    my ( $home ) = @_;
+    my $log_file = File::Spec->catfile($home, '.cpanm', 'build.log');
+    my $tempfile = File::Temp->new(
+        SUFFIX => '.log',
+        UNLINK => 0,
+    );
+    copy($log_file, $tempfile->filename);
+    diag("For details, please consult $tempfile")
+}
+
 sub is_dist_root {
     my ( @path ) = @_;
 
@@ -109,7 +121,8 @@ $ENV{'PATH'} = join(':', $ENV{'PERLBREW_PATH'}, $pristine_path);
 
 plan tests => 1;
 
-my $tmpdir = File::Temp->newdir;
+my $tmpdir  = File::Temp->newdir;
+my $tmphome = File::Temp->newdir;
 
 my $pid = fork;
 if(!defined $pid) {
@@ -117,7 +130,7 @@ if(!defined $pid) {
     exit 1;
 } elsif($pid) {
     waitpid $pid, 0;
-    ok !$?, "cpanm should successfully install your dist with no issues";
+    ok !$?, "cpanm should successfully install your dist with no issues" or copy_log_file($tmphome->dirname);
 } else {
     close STDOUT;
     close STDERR;
@@ -132,6 +145,9 @@ if(!defined $pid) {
     }
     chdir File::Spec->catdir(@path); # exit test directory
 
+    # override where cpanm puts its log file
+    $ENV{'HOME'} = $tmphome->dirname;
+
     {{
         unless($should_test_deps) {
             return <<'END_PERL';
@@ -193,7 +209,7 @@ Dist::Zilla::Plugin::Test::LocalBrew - Verify that your distribution tests well
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -257,7 +273,7 @@ Rob Hoelz <rob@hoelz.ro>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Rob Hoelz.
+This software is copyright (c) 2013 by Rob Hoelz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
